.. :changelog:

History
-------

0.1.0 (2017-12-29)
++++++++++++++++++

* First release on PyPI.
* Initial models and REST API.

0.2.0 (2018-01-05)
++++++++++++++++++

* Added REST API filters.
* Added URLs to pubmed article and NCBI utils.
